#!/bin/bash
###############################################################################
# Copyright (c) 2017 Genialist Software Ltd. All rights reserved.             #
###############################################################################

typeset EXE_BIN=""

typeset EXE_PID="java -jar java/pFramework.jar -class tv.genialist.fwrk.media.library.pMediaLibraryHTTPViewer"

typeset EXE_CMD="java -jar java/pFramework.jar -class tv.genialist.fwrk.media.library.pMediaLibraryHTTPViewer"

typeset EXE_DESC="Genialist Media Server"

###############################################################################
# Writes a message on stdout with orange color if output is terminal

echoWarning() {
	if [ -t 1 ] ; then
		echo -e "\e[1;31m"$*"\e[0m"
	else
		echo $*
	fi
}

###############################################################################
# Writes third-party tool versions

echoTools() {
	for i in ffmpeg mediainfo java AtomicParsley mkvextract mkvpropedit ; do
		if which $i >/dev/null 2>/dev/null ; then 
			echo $i: OK
			case $i in
			AtomicParsley)	echo -e "\t" `$i -version | head -1`
					;;
			java)		echo -e "\t" `$i -version 2>&1 | head -1`
					;;
			ffmpeg)		echo -e "\t" `$i -version | head -1`
					;;
			mediainfo)	echo -e "\t" `$i --version | tail -1`
					;;	
			*)		echo -e "\t" `$i --version | head -1`
					;;
			esac
		else
			echoWarning $i: cannot be found or not installed, some features may not work properly
		fi
	done
	echo 
}

###############################################################################
# Finds the PID of a process by searching its command and some arguments

findpid() {
        /bin/ps awxf | egrep "$1" | fgrep -v 'egrep' | fgrep -v "${SCRIPT}" | fgrep -v "grep" | awk '{ print $1 }'
}

###############################################################################
# check if EXE_CMD runs without full path name

checkexe() {
        typeset EXE_CMD_BASENAME=`basename "${1}"`
        typeset EXE_DESC="$2"

        /bin/ps awx | egrep "${EXE_CMD_BASENAME}" | fgrep -v 'egrep' | fgrep -v "${SCRIPT}" | awk '{ print $5 }' | while read CMD ; do
                case "${CMD}" in
                ${EXE_CMD_BASENAME})
                        echo "${EXE_DESC}" running but started without its full command line path, this script cannot determine if this process can be managed
                        exit -1
                        ;;
                ./${EXE_CMD_BASENAME})
                        echo "${EXE_DESC}" running but started without its full command line path, this script cannot determine if this process can be managed
                        exit -1
                        ;;
                esac
        done
}

###############################################################################
# Stops a process and retry if necessary up to 20 seconds

stop() {
        typeset EXE_BIN="$1"
        typeset EXE_PID="$2"
        typeset EXE_CMD="$3"
        typeset EXE_DESC="$4"
        
        checkexe "${EXE_CMD}" "${EXE_DESC}"
        [ $? != 0 ] && exit $?

        for i in 1 2 3 4 ; do
                PID=`findpid "${EXE_PID}"`
                if [ "${PID}" = "" ] ; then
                        echo "${EXE_DESC}" not running
                        return 0
                else
                	echo "${EXE_DESC}" running with pid ${PID}
                        echo "Stopping ${EXE_DESC}..."
                        case "$i" in
                        4)	kill -9 "${PID}"
                        	;;
                        3)      kill -9 "${PID}"
                        	;;
                        2)
                                kill "${PID}"
                                sleep 5
                                ;;
                        1)
                        	typeset STOPFILE="${HOME}/.pFramework/${USER}/shutdown/tv.genialist.fwrk.media.library.pMediaLibraryHTTPViewer/shutdown"
                        	typeset STOPDIR=`dirname "${STOPFILE}"`
                        	[ ! -d "${STOPDIR}" ] && mkdir -p "${STOPDIR}"
                        	touch "${STOPFILE}"
                        	sleep 15
                        	rm "${STOPFILE}"
                        	;;
                        esac
                fi
        done
        return 1
}

###############################################################################
# Starts a process and waits 5s (or more) to ensure it is started

start() {
        typeset EXE_BIN="$1"
        typeset EXE_PID="$2"
        typeset EXE_CMD="$3"
        typeset EXE_DESC="$4"
	typeset EXE_SLEEP="$5"

	checkexe "${EXE_CMD}" "${EXE_DESC}"
	[ $? != 0 ] && exit $?
	
	[ "${EXE_SLEEP}" = "" ] && EXE_SLEEP=5

        PID=`findpid "${EXE_PID}"`
        if [ "${PID}" != "" ] ; then
                echo "${EXE_DESC}" running with pid ${PID}
                return 0
        else
                echo "Starting ${EXE_DESC}..."
                if [ "${EXE_BIN}" = "" ] ; then
                	nohup ${EXE_CMD} >>/dev/null 2>>/dev/null &
                else
			cd "${EXE_BIN}"
			case "${EXE_CMD}" in
			/*)
				nohup ${EXE_CMD} >>/dev/null 2>>/dev/null &
				;;
			*)
				nohup "${EXE_BIN}"/${EXE_CMD} >>/dev/null 2>>/dev/null &
				;;
			esac
		fi

                sleep "${EXE_SLEEP}"
                PID=`findpid "${EXE_PID}"`
                if [ "${PID}" = "" ] ; then
                        echo "Failed to start ${EXE_DESC}"
                else
                        echo "Started ${EXE_DESC}"
                	echo "${EXE_DESC}" running with pid ${PID}
			return 0
                fi
        fi
        return 1
}

###############################################################################
# Prints the running PID of a process if running

check() {
        typeset EXE_PID="$1"
        typeset EXE_CMD="$2"
        typeset EXE_DESC="$3"

	checkexe "${EXE_CMD}" "${EXE_DESC}"
	[ $? != 0 ] && exit $?

        PID=`findpid "${EXE_PID}"`
        if [ "${PID}" != "" ] ; then
                echo "${EXE_DESC}" running with pid ${PID}
                return 0
        else
        	echo "${EXE_DESC}" not running
        	return 1
        fi
}

###############################################################################

SCRIPT="$0"
DIRSCRIPT=`dirname "$0"`
DIRSCRIPT=`(cd "${DIRSCRIPT}" ; pwd)`

###############################################################################

case "$1" in
'stop')
        stop "${EXE_BIN}" "${EXE_PID}" "${EXE_CMD}" "${EXE_DESC}"
        ;;
'check')
	echoTools
	
        check "${EXE_PID}" "${EXE_CMD}" "${EXE_DESC}"
        ;;
*)
	echoTools

	(cd "${DIRSCRIPT}/.."
        start "${EXE_BIN}" "${EXE_PID}" "${EXE_CMD}" "${EXE_DESC}")
        ;;
esac

###############################################################################
###  END OF FILE  #############################################################
###############################################################################

