#!/bin/bash
###############################################################################
# Copyright (c) 2017 Genialist Software Ltd. All rights reserved.             #
###############################################################################

SCRIPT="$0"
DIRSCRIPT=`dirname "$0"`
DIRSCRIPT=`(cd "${DIRSCRIPT}" ; pwd)`

###############################################################################
# Common functions

echoSection() {
	echo
	if [ -t 1 ] ; then
		echo -e "\033[1;36m${1}\e[0m"
	else
		echo $*
	fi
	echo
}

###############################################################################
# Install ffmpeg

installFFmpeg() {
	echoSection "Install ffmpeg..."

	case `uname -n` in
	stretch)
		sudo sh -c 'echo deb http://ftp.uk.debian.org/debian jessie-backports main >> /etc/apt/sources.list'
		sudo apt-get update
		sudo apt-get install ffmpeg
		;;
	jessie)
		sudo sh -c 'echo deb http://ftp.uk.debian.org/debian jessie-backports main >> /etc/apt/sources.list'
		sudo apt-get update
		sudo apt-get install ffmpeg
		;;

	*)
		sudo add-apt-repository ppa:mc3man/trusty-media
		sudo apt-get update
		sudo apt-get dist-upgrade
		sudo apt-get install ffmpeg
		;;
	esac
}

###############################################################################
# Install MediaInfo:

installMediaInfo() {
	echoSection "Install MediaInfo..."

	sudo apt-get install mediainfo
}

###############################################################################
# Install Atomic Parsley

installAtomicParsley() {
	echoSection "Install Atomic Parsley..."

	sudo apt-get install atomicparsley
}

###############################################################################
# Install MKVToolnix:

installMKVToolnix() {
	echoSection "Install MKVToolnix..."

	wget -q -O - https://mkvtoolnix.download/gpg-pub-moritzbunkus.txt | sudo apt-key add -

	case `uname -n` in
	stretch)
		sudo sh -c 'echo deb https://mkvtoolnix.download/debian/ stretch main > /etc/apt/sources.list.d/mkvtoolnix.download.list'
		sudo sh -c 'echo deb-src https://mkvtoolnix.download/debian/ stretch main >> /etc/apt/sources.list.d/mkvtoolnix.download.list'

		sudo apt-get install apt-transport-https
		;;
	jessie)
		sudo sh -c 'echo deb https://mkvtoolnix.download/debian/ jessie main > /etc/apt/sources.list.d/mkvtoolnix.download.list'
		sudo sh -c 'echo deb-src https://mkvtoolnix.download/debian/ jessie main >> /etc/apt/sources.list.d/mkvtoolnix.download.list'

		sudo apt-get install apt-transport-https
		;;
	ubuntu-cosmic)
		sudo su -c 'echo deb https://mkvtoolnix.download/ubuntu/ bionic main > /etc/apt/sources.list.d/mkvtoolnix.download.list'
		sudo su -c 'echo deb-src https://mkvtoolnix.download/ubuntu/ bionic main >> /etc/apt/sources.list.d/mkvtoolnix.download.list'
		;;
	ubuntu-bionic)
		sudo su -c 'echo deb https://mkvtoolnix.download/ubuntu/ bionic main > /etc/apt/sources.list.d/mkvtoolnix.download.list'
		sudo su -c 'echo deb-src https://mkvtoolnix.download/ubuntu/ bionic main >> /etc/apt/sources.list.d/mkvtoolnix.download.list'
		;;
	ubuntu-xenial)
		sudo su -c 'echo deb https://mkvtoolnix.download/ubuntu/ xenial main > /etc/apt/sources.list.d/mkvtoolnix.download.list'
		sudo su -c 'echo deb-src https://mkvtoolnix.download/ubuntu/ xenial main >> /etc/apt/sources.list.d/mkvtoolnix.download.list'
		;;
	ubuntu-artful)
		sudo su -c 'echo deb https://mkvtoolnix.download/ubuntu/ artful main > /etc/apt/sources.list.d/mkvtoolnix.download.list'
		sudo su -c 'echo deb-src https://mkvtoolnix.download/ubuntu/ artful main >> /etc/apt/sources.list.d/mkvtoolnix.download.list'
		;;
	esac

	sudo apt update
	sudo apt-get install mkvtoolnix
}

###############################################################################
# Install Arial.ttf

installArial() {
	echoSection "Install Arial Font..."

	sudo apt-get install ttf-mscorefonts-installer
	sudo fc-cache
}

###############################################################################
# Install Java

installJava() {
	echoSection "Install Java..."

	case `uname -n` in
	stretch)
		sudo apt-get install default-jre
		;;
	jessie)
		sudo apt-get install default-jre
		;;
	*)
		sudo add-apt-repository ppa:webupd8team/java
		sudo apt-get update
		sudo apt-get install oracle-java8-installer
		;;
	esac
}

###############################################################################
# Install Genialist Media Server:

installFFmpeg
installMediaInfo
installAtomicParsley
installMKVToolnix
installArial
installJava

echoSection "Install Genialist Media Server..."

[ ! -d "${HOME}/.pFramework" ] && mkdir "${HOME}/.pFramework"
cp "${DIRSCRIPT}/../java/gms-seed-0000.bin" "${HOME}/.pFramework"

[ ! -d "${HOME}/Music" ] && mkdir "${HOME}/Music"

###############################################################################
###  END OF FILE  #############################################################
###############################################################################
